==> MMDX-v1.10a-src.zip: MMDX-v1.10a-src/MikuMikuDanceXNA/Stages/CameraAnimationPlayer.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MikuMikuDance.XNA.Motion;
using Microsoft.Xna.Framework;

namespace MikuMikuDance.XNA.Stages
{
    /// <summary>
    /// [Vt@CJ[VĐAj[VvC[
    /// </summary>
    public class CameraAnimationPlayer
    {
        //J
        MMDCamera camera;
        //݂̃[Vꗗ
        CameraMotionTrack[] mmdMotion = new CameraMotionTrack[MikuMikuDanceXNA.MotionTrackCap];

        /// <summary>
        /// b̃t[
        /// </summary>
        public int FramePerSecond { get; set; }
        

        internal CameraAnimationPlayer(MMDCamera camera)
        {
            this.camera = camera;
            FramePerSecond = 30;//MMD30t[/bW
            for (int i = 0; i < mmdMotion.Length; i++)
                mmdMotion[i] = new CameraMotionTrack();
        }
        /// <summary>
        /// [VZbg
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        public void Reset(int index)
        {
            mmdMotion[index].Reset();
        }
        /// <summary>
        /// [V[vvCǂ𒲂ׂ
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        /// <returns>[vvCȂtrue</returns>
        public bool IsLoopPlay(int index)
        {
            return mmdMotion[index].IsLoopPlay;
        }
        /// <summary>
        /// [V̍ĐԂ擾
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        /// <returns>ĐȂtrue</returns>
        public bool IsPlay(int index)
        {
            return (mmdMotion[index].IsPlay);
        }

        /// <summary>
        /// JĂgbNɃ[VZbg
        /// </summary>
        /// <param name="index">gbNԍ(0`MikuMikuDanceXNA.MotionTrackCap)</param>
        /// <param name="motion">ZbgMMDXe[W[Vf[^</param>
        /// <param name="SetStartPos">0t[̃f[^ŃJ</param>
        /// <returns>ZbggbN̔ԍBJĂgbN-1</returns>
        public void SetMotion(int index, MMDStageMotion motion, bool SetStartPos)
        {
            if (motion.MotionData.CameraMotions.Length == 0)
                throw new ApplicationException("J[V܂܂Ă܂");
            //IuWFNgv[̃[VgbNɃf[^Zbg
            mmdMotion[index].Clear();
            motion.ToCameraUse = true;
            mmdMotion[index].motion = motion;
            mmdMotion[index].IsEmpty = false;
            mmdMotion[index] = mmdMotion[index];//IuWFNgv[Ă
            if (SetStartPos)
                Update(index);
        }

        /// <summary>
        /// w肵gbNɃ[VZbg
        /// </summary>
        /// <param name="motion">ZbgMMD[Vf[^</param>
        /// <param name="SetStartPos">0t[̃f[^ŃJ</param>
        public int SetMotion(MMDStageMotion motion, bool SetStartPos)
        {
            int Index = -1;
            for (Index = 0; Index < MikuMikuDanceXNA.MotionTrackCap; Index++)
                if (mmdMotion[Index].IsEmpty)
                    break;
            if (Index >= MikuMikuDanceXNA.MotionTrackCap)
                return -1;
            SetMotion(Index, motion, SetStartPos);
            return Index;
        }
        /// <summary>
        /// [VĐ
        /// </summary>
        /// <param name="index">[VCfbNXԍ</param>
        /// <param name="bLoopPlay">[vvC</param>
        public void Start(int index, bool bLoopPlay)
        {
            if (mmdMotion[index].IsEmpty)
                throw new ApplicationException("[Vf[^ZbgĂȂ̂Starts");
            mmdMotion[index].Start();
            mmdMotion[index].IsLoopPlay = bLoopPlay;
        }
        /// <summary>
        /// [VXgbv
        /// </summary>
        public void Stop(int index)
        {
            mmdMotion[index].Stop();
        }

        internal void Update(int motionIndex)
        {
            for (int i = (motionIndex < 0 ? 0 : motionIndex); i < (motionIndex < 0 ? mmdMotion.Length : motionIndex + 1); i++)
            {
                //Đǂ`FbN
                if (!mmdMotion[i].IsEmpty && mmdMotion[i].IsPlay)
                {
                    //݂̍Đt[XV
                    mmdMotion[i].UpdateFrame(camera.Player.FramePerSecond);
                    mmdMotion[i].ApplyMotion(camera);
                }
            }
        }
    }
}

==> MMDX-v1.20a-src.zip: MMDX-v1.20a-src/MikuMikuDanceXNA/Stages/CameraAnimationPlayer.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MikuMikuDance.XNA.Motion;
using Microsoft.Xna.Framework;

namespace MikuMikuDance.XNA.Stages
{
    /// <summary>
    /// [Vt@CJ[VĐAj[VvC[
    /// </summary>
    public class CameraAnimationPlayer
    {
        //J
        MMDCamera camera;
        //݂̃[Vꗗ
        CameraMotionTrack[] mmdMotion = new CameraMotionTrack[MikuMikuDanceXNA.MotionTrackCap];

        /// <summary>
        /// b̃t[
        /// </summary>
        public int FramePerSecond { get; set; }
        

        internal CameraAnimationPlayer(MMDCamera camera)
        {
            this.camera = camera;
            FramePerSecond = 30;//MMD30t[/bW
            for (int i = 0; i < mmdMotion.Length; i++)
                mmdMotion[i] = new CameraMotionTrack();
        }
        /// <summary>
        /// [VZbg
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        public void Reset(int index)
        {
            mmdMotion[index].Reset();
        }
        /// <summary>
        /// [V[vvCǂ𒲂ׂ
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        /// <returns>[vvCȂtrue</returns>
        public bool IsLoopPlay(int index)
        {
            return mmdMotion[index].IsLoopPlay;
        }
        /// <summary>
        /// [V̍ĐԂ擾
        /// </summary>
        /// <param name="index">[VgbNԍ</param>
        /// <returns>ĐȂtrue</returns>
        public bool IsPlay(int index)
        {
            return (mmdMotion[index].IsPlay);
        }

        /// <summary>
        /// JĂgbNɃ[VZbg
        /// </summary>
        /// <param name="index">gbNԍ(0`MikuMikuDanceXNA.MotionTrackCap)</param>
        /// <param name="motion">ZbgMMDXe[W[Vf[^</param>
        /// <param name="SetStartPos">0t[̃f[^ŃJ</param>
        /// <returns>ZbggbN̔ԍBJĂgbN-1</returns>
        public void SetMotion(int index, MMDStageMotion motion, bool SetStartPos)
        {
            if (motion.MotionData.CameraMotions.Length == 0)
                throw new ApplicationException("J[V܂܂Ă܂");
            //IuWFNgv[̃[VgbNɃf[^Zbg
            mmdMotion[index].Clear();
            motion.ToCameraUse = true;
            mmdMotion[index].motion = motion;
            mmdMotion[index].IsEmpty = false;
            mmdMotion[index] = mmdMotion[index];//IuWFNgv[Ă
            if (SetStartPos)
                Update(index, true);
        }

        /// <summary>
        /// w肵gbNɃ[VZbg
        /// </summary>
        /// <param name="motion">ZbgMMD[Vf[^</param>
        /// <param name="SetStartPos">0t[̃f[^ŃJ</param>
        public int SetMotion(MMDStageMotion motion, bool SetStartPos)
        {
            int Index = -1;
            for (Index = 0; Index < MikuMikuDanceXNA.MotionTrackCap; Index++)
                if (mmdMotion[Index].IsEmpty)
                    break;
            if (Index >= MikuMikuDanceXNA.MotionTrackCap)
                return -1;
            SetMotion(Index, motion, SetStartPos);
            return Index;
        }
        /// <summary>
        /// [VĐ
        /// </summary>
        /// <param name="index">[VCfbNXԍ</param>
        /// <param name="bLoopPlay">[vvC</param>
        public void Start(int index, bool bLoopPlay)
        {
            if (mmdMotion[index].IsEmpty)
                throw new ApplicationException("[Vf[^ZbgĂȂ̂Starts");
            mmdMotion[index].Start();
            mmdMotion[index].IsLoopPlay = bLoopPlay;
        }
        /// <summary>
        /// [VXgbv
        /// </summary>
        public void Stop(int index)
        {
            mmdMotion[index].Stop();
        }

        internal void Update(int motionIndex, bool ForceUpdate)
        {
            for (int i = (motionIndex < 0 ? 0 : motionIndex); i < (motionIndex < 0 ? mmdMotion.Length : motionIndex + 1); i++)
            {
                //Đǂ`FbN
                if ((!mmdMotion[i].IsEmpty && mmdMotion[i].IsPlay) || ForceUpdate)
                {
                    //݂̍Đt[XV
                    mmdMotion[i].UpdateFrame(camera.Player.FramePerSecond);
                    mmdMotion[i].ApplyMotion(camera);
                }
            }
        }
    }
}
